GestureDebugEvent class

Internal debug event for gesture processing

Constructors

GestureDebugEvent({required GestureDebugEventType type, required String component, required String message, Map<String, dynamic> data = const {}, GestureDebugSeverity severity = GestureDebugSeverity.debug, String? entityId, String? gesturePhase})

Properties

component String
final
data Map<String, dynamic>
final
entityId String?
final
gesturePhase String?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity GestureDebugSeverity
final
timestamp DateTime
final
type GestureDebugEventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Human-readable format for console output
override
toStructuredMap() Map<String, dynamic>
Structured format for workbench analysis

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromStructuredMap(Map<String, dynamic> map) GestureDebugEvent
Creates event from structured map (for deserialization)