GraphDefaultNodeRendererStyle class abstract

Controls node appearance with color and dimension options that automatically update based on interaction states.

See also:

Annotations
  • @freezed

Constructors

GraphDefaultNodeRendererStyle({@Default.new(Color(0xFFE2E8F0)) Color color, @Default.new(Color(0xFF64748B)) Color borderColor, @Default.new(Color(0xFF1E293B)) Color labelColor, @Default.new(Colors.grey) Color idColor, @Default.new(Colors.red) Color hoverColor, @Default.new(Colors.green) Color selectedHoverColor, @Default.new(Color(0xFF4A5568)) Color selectedBorderColor, @Default.new(Colors.yellow) Color highlightColor, double? radius, double? width, double? height, @Default.new(50) double minWidth, @Default.new(50) double minHeight, @Default.new(2) double borderWidth, @Default.new(2) double hoverBorderWidth, @Default.new(2) double selectedBorderWidth, @Default.new(2) double selectedHoverBorderWidth, @Default.new(2) double selectedUnhoverBorderWidth, @Default.new(GraphDefaultNodeRendererShape.circle) GraphDefaultNodeRendererShape shape, @Default.new(EdgeInsets.all(8)) EdgeInsets padding})
Creates a style configuration with default values for all properties.
const
factory

Properties

borderColor Color
The color of the node's border.
no setterinherited
borderWidth double
The width of the node's border in normal state.
no setterinherited
color Color
The background color of the node.
no setterinherited
copyWith → $GraphDefaultNodeRendererStyleCopyWith<GraphDefaultNodeRendererStyle>
Create a copy of GraphDefaultNodeRendererStyle with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
height double?
The fixed height of the node.
no setterinherited
highlightColor Color
The background color for emphasized nodes.
no setterinherited
hoverBorderWidth double
The width of the node's border when hovered.
no setterinherited
hoverColor Color
The background color when the node is hovered.
no setterinherited
idColor Color
The color of the node's ID text.
no setterinherited
labelColor Color
The color of the node's label text.
no setterinherited
minHeight double
The minimum height constraint for the node.
no setterinherited
minWidth double
The minimum width constraint for the node.
no setterinherited
padding EdgeInsets
The padding inside the node's border.
no setterinherited
radius double?
The radius of circular nodes.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedBorderColor Color
The border color when the node is selected.
no setterinherited
selectedBorderWidth double
The width of the node's border when selected.
no setterinherited
selectedHoverBorderWidth double
The width of the node's border when both selected and hovered.
no setterinherited
selectedHoverColor Color
The background color when the node is both selected and hovered.
no setterinherited
selectedUnhoverBorderWidth double
The width of the node's border when selection ends.
no setterinherited
shape GraphDefaultNodeRendererShape
The shape of the node. Can be either circle or rectangle.
no setterinherited
width double?
The fixed width of the node.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited