GraphDragUpdateEvent class

Event fired during a drag operation on one or more entities.

Inheritance

Constructors

GraphDragUpdateEvent({required List<GraphId> entityIds, required PointerEventDetails details, required Offset delta})
const

Properties

delta Offset
The change in position since the last update.
final
details PointerEventDetails
final
entityIds List<GraphId>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

Helper to get the links involved in this event from the graph.
inherited
getNodes(Graph graph) Iterable<GraphNode>
Helper to get the nodes involved in this event from the graph.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited