GraphEntityEvent class abstract

Base class for events related to one or more graph entities.

Inheritance
Implementers

Constructors

GraphEntityEvent(List<GraphId> entityIds)
const

Properties

entityIds List<GraphId>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

Helper to get the links involved in this event from the graph.
getNodes(Graph graph) Iterable<GraphNode>
Helper to get the nodes involved in this event from the graph.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited