nodePositions property
List of predefined node positions.
Used to set initial positions or fix nodes at specific locations during layout.
Implementation
final List<GraphNodeLayoutPosition> nodePositions;
List of predefined node positions.
Used to set initial positions or fix nodes at specific locations during layout.
final List<GraphNodeLayoutPosition> nodePositions;