GraphShape class abstract interface

An interface for defining node shapes in the graph.

Provides intersection calculation between a shape and a line, which is used to determine where links should connect to nodes.

Implementations include GraphCircle and GraphRectangle for standard node shapes.

See also:

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLineIntersections(Rect bounds, GraphLine line) Set<Offset>
Calculates intersection points between this shape and a line.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited