createLinkViewBehavior method

  1. @override
GraphLinkViewBehavior createLinkViewBehavior()
override

Creates the behavior configuration for link rendering.

Override this method to customize how links between nodes are displayed and interact with user input.

Implementation

@override
GraphLinkViewBehavior createLinkViewBehavior() {
  const thickness = 30.0; // Consider making this configurable
  return GraphLinkViewBehavior(
    builder: (
      context,
      graph,
      link,
      sourceView,
      targetView,
      routing,
      geometry,
      _,
    ) =>
        GraphDefaultLinkRenderer(
      link: link,
      sourceView: sourceView,
      targetView: targetView,
      routing: routing,
      geometry: geometry,
      thickness: thickness,
    ),
    routing: linkRouting,
    // Default tooltip behavior for links could be added here if desired
    // tooltipBehavior: GraphTooltipBehavior(...)
  );
}