GraphDragUpdateEvent class
Event fired during a drag operation on one or more entities.
- Inheritance
-
- Object
- GraphEvent
- GraphEntityEvent
- GraphDragUpdateEvent
Constructors
-
GraphDragUpdateEvent({required List<
GraphId> entityIds, required PointerEventDetails details, required Offset delta}) -
const
Properties
Methods
-
getLinks(
Graph graph) → Iterable< GraphLink> -
Helper to get the links involved in this event from the graph.
inherited
-
getNodes(
Graph graph) → Iterable< GraphNode> -
Helper to get the nodes involved in this event from the graph.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited