GraphEntityEvent class abstract
Base class for events related to one or more graph entities.
- Inheritance
-
- Object
- GraphEvent
- GraphEntityEvent
- Implementers
Constructors
-
GraphEntityEvent(List<
GraphId> entityIds) -
const
Properties
Methods
-
getLinks(
Graph graph) → Iterable< GraphLink> - Helper to get the links involved in this event from the graph.
-
getNodes(
Graph graph) → Iterable< GraphNode> - Helper to get the nodes involved in this event from the graph.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited