GraphHitTestResult class
Detailed information about what was hit during a gesture.
Used to determine whether GraphView should consume a gesture or pass it through to parent widgets.
Constructors
- GraphHitTestResult({required Offset localPosition, GraphNode? node, GraphLink? link})
-
Creates a hit test result.
const
Properties
- entity → GraphEntity?
-
The entity that was hit, if any.
no setter
- entityId → GraphId?
-
The ID of the entity that was hit, if any.
no setter
- hasEntity → bool
-
Whether any graph entity was hit.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasLink → bool
-
Whether a link was hit.
no setter
- hasNode → bool
-
Whether a node was hit.
no setter
- isBackground → bool
-
Whether this is a background hit (no entities).
no setter
- link → GraphLink?
-
The link that was hit, if any.
final
- localPosition → Offset
-
The local position where the hit test occurred.
final
- node → GraphNode?
-
The node that was hit, if any.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited