GraphHoverEvent class
Event fired when the mouse pointer enters the area of an entity.
- Inheritance
-
- Object
- GraphEvent
- GraphHoverEvent
Constructors
- GraphHoverEvent({required GraphId entityId, required PointerEventDetails details})
-
const
Properties
- details → PointerEventDetails
-
final
- entityId → GraphId
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getLink(
Graph graph) → GraphLink? - Helper to get the link involved (if it's a link).
-
getNode(
Graph graph) → GraphNode? - Helper to get the node involved (if it's a node).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited